@@ -594,12 +594,12 @@ class CreateL3Policy(neutronV20.CreateCommand):
             for external_segment in parsed_args.external_segments:
                 external_segment_id = neutronV20.find_resourceid_by_name_or_id(
                     self.get_client(), 'external_segment',
-                    external_segment.keys()[0])
-                ipaddrs = external_segment.itervalues().next()
+                    list(external_segment.keys())[0])
+                ipaddrs = next(iter(external_segment.values()))
                 if ipaddrs is "":
                     ipaddrs = []
                 else:
-                    ipaddrs = external_segment.itervalues().next().split(':')
+                    ipaddrs = next(iter(external_segment.values())).split(':')
                 external_segments_dict[external_segment_id] = ipaddrs
 
             body[self.resource]['external_segments'] = external_segments_dict
@@ -677,12 +677,12 @@ class UpdateL3Policy(neutronV20.UpdateCommand):
                     break
                 external_segment_id = neutronV20.find_resourceid_by_name_or_id(
                     self.get_client(), 'external_segment',
-                    external_segment.keys()[0])
-                ipaddrs = external_segment.itervalues().next()
+                    list(external_segment.keys())[0])
+                ipaddrs = next(iter(external_segment.values()))
                 if ipaddrs is "":
                     ipaddrs = []
                 else:
-                    ipaddrs = external_segment.itervalues().next().split(':')
+                    ipaddrs = next(iter(external_segment.values())).split(':')
                 external_segments_dict[external_segment_id] = ipaddrs
 
             body[self.resource]['external_segments'] = external_segments_dict
