@@ -17,14 +17,16 @@
 import json
 import logging
 import os
-import string
 
 from heatclient.common import template_utils
 
+from neutronclient._i18n import _
 from neutronclient.common import exceptions as exc
-from neutronclient.i18n import _
+from neutronclient.common import utils as n_utils
 from neutronclient.neutron import v2_0 as neutronV20
 
+from gbpclient.common import utils
+
 
 class ListServiceChainInstance(neutronV20.ListCommand):
     """List service chain instances that belong to a given tenant."""
@@ -90,8 +92,7 @@ class CreateServiceChainInstance(neutronV20.CreateCommand):
                     parsed_args.consumer_ptg)
         neutronV20.update_dict(parsed_args, body[self.resource],
                                ['name', 'tenant_id', 'description',
-                                'servicechain_spec', 'provider_ptg',
-                                'consumer_ptg', 'param_values'])
+                                'param_values'])
         return body
 
 
@@ -134,9 +135,7 @@ class UpdateServiceChainInstance(neutronV20.UpdateCommand):
                     self.get_client(), 'policy_target_group',
                     parsed_args.consumer_ptg)
         neutronV20.update_dict(parsed_args, body[self.resource],
-                               ['name', 'description',
-                                'servicechain_spec', 'provider_ptg',
-                                'consumer_ptg', 'param_values'])
+                               ['name', 'description', 'param_values'])
         return body
 
 
@@ -178,8 +177,8 @@ class CreateServiceProfile(neutronV20.CreateCommand):
         parser.add_argument(
             '--description',
             help=_('Description of the Service Profile.'))
-        parser.add_argument(
-            '--shared', type=bool,
+        n_utils.add_boolean_argument(
+            parser, '--shared', dest='shared',
             help=_('Shared flag'))
         parser.add_argument(
             '--vendor',
@@ -216,8 +215,8 @@ class UpdateServiceProfile(neutronV20.UpdateCommand):
         parser.add_argument(
             '--description',
             help=_('Description of the Service Profile.'))
-        parser.add_argument(
-            '--shared', type=bool,
+        n_utils.add_boolean_argument(
+            parser, '--shared', dest='shared',
             help=_('Shared flag'))
         parser.add_argument(
             '--vendor',
@@ -288,8 +287,8 @@ class CreateServiceChainNode(neutronV20.CreateCommand):
         parser.add_argument(
             '--config',
             help=_('Service Configuration for the Service Chain Node.'))
-        parser.add_argument(
-            '--shared', type=bool,
+        n_utils.add_boolean_argument(
+            parser, '--shared', dest='shared',
             help=_('Shared flag'))
         parser.add_argument(
             '--template-file',
@@ -338,8 +337,8 @@ class UpdateServiceChainNode(neutronV20.UpdateCommand):
         parser.add_argument(
             '--config',
             help=_('Service Configuration for the Service Chain Node.'))
-        parser.add_argument(
-            '--shared', type=bool,
+        n_utils.add_boolean_argument(
+            parser, '--shared', dest='shared',
             help=_('Shared flag'))
 
     def args2body(self, parsed_args):
@@ -394,10 +393,10 @@ class CreateServiceChainSpec(neutronV20.CreateCommand):
             '--description',
             help=_('Description of the Service Chain Specification.'))
         parser.add_argument(
-            '--nodes', metavar='NODES', type=string.split,
-            help=_('Service Chain Node ID or name of the Service Chain Node'))
-        parser.add_argument(
-            '--shared', type=bool,
+            '--nodes', metavar='NODES', type=utils.str2list,
+            help=_('Comma separated list of Service Chain Nodes'))
+        n_utils.add_boolean_argument(
+            parser, '--shared', dest='shared',
             help=_('Shared flag'))
 
     def args2body(self, parsed_args):
@@ -423,16 +422,19 @@ class UpdateServiceChainSpec(neutronV20.UpdateCommand):
 
     def add_known_arguments(self, parser):
         parser.add_argument(
-            '--nodes', type=string.split,
-            help=_('List of Service Chain Node IDs or names of the Service '
-                   'Chain Nodes'))
-        parser.add_argument(
-            '--shared', type=bool,
+            '--nodes', type=utils.str2list,
+            help=_('New comma separated list of Service Chain Nodes '
+                   '(to unset use "")'))
+        n_utils.add_boolean_argument(
+            parser, '--shared', dest='shared',
             help=_('Shared flag'))
 
     def args2body(self, parsed_args):
         body = {self.resource: {}, }
-        if parsed_args.nodes:
+
+        if parsed_args.nodes == []:
+            body[self.resource]['nodes'] = []
+        elif parsed_args.nodes:
             body[self.resource]['nodes'] = [
                 neutronV20.find_resourceid_by_name_or_id(
                     self.get_client(),
